==> tabular-data-manager-2.4.0-20141003.093405-1-sources.jar: org/gcube/portlets/user/td/client/resource/TabularDataResources.java <==
/**
 * 
 */
package org.gcube.portlets.user.td.client.resource;

import com.google.gwt.core.client.GWT;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.ImageResource;

/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public interface TabularDataResources extends ClientBundle {
	
	public static final TabularDataResources INSTANCE =  GWT.create(TabularDataResources.class);
	
	@Source("arrow-refresh_32.png")
	ImageResource refresh32();
	
	@Source("arrow-refresh.png")
	ImageResource refresh();
	
	
	@Source("page-white-add_32.png")
	ImageResource open32();
	
	@Source("page-white-close_32.png")
	ImageResource close32();
	
	@Source("page-white-close.png")
	ImageResource close();
	
	@Source("page-white-share_32.png")
	ImageResource share32();
	
	@Source("page-white-share.png")
	ImageResource share();
	
	@Source("disk.png")
	ImageResource save();
	
	@Source("disk_32.png")
	ImageResource save32();
	
	@Source("properties.png")
	ImageResource properties();
	
	
	@Source("sdmx.png")
	ImageResource sdmx();
	
	@Source("sdmx_32.png")
	ImageResource sdmx32();
	
	@Source("gis.png")
	ImageResource gis();
	
	@Source("gis_32.png")
	ImageResource gis32();
	
	
	@Source("csv.png")
	ImageResource csv();
	
	@Source("json.png")
	ImageResource json();
	
	
	@Source("chart-bar.png")
	ImageResource chart();
	
	@Source("chart-bar_32.png")
	ImageResource chartBar32();
	
	@Source("chart-bulls.png")
	ImageResource chartBulls();

	@Source("chart-bulls_32.png")
	ImageResource chartBulls32();

	@Source("chart-curve.png")
	ImageResource chartCurve();
	
	@Source("chart-curve_32.png")
	ImageResource chartCurve32();
	
	
	@Source("chart-pie.png")
	ImageResource chartPie();
	
	@Source("chart-pie_32.png")
	ImageResource chartPie32();
	
	
	@Source("RStudio.png")
	ImageResource rstudio();
	
	@Source("RStudio_32.png")
	ImageResource rstudio32();
	
	@Source("statistical.png")
	ImageResource statistical();
	
	@Source("statistical_32.png")
	ImageResource statistical32();
	
	@Source("table-validate_32.png")
	ImageResource validation32();
	

	@Source("table-validate.png")
	ImageResource validation();
	
	
	@Source("rules.png")
	ImageResource rules();
	
	@Source("rules_32.png")
	ImageResource rules32();
	
	
	@Source("table-filter_32.png")
	ImageResource filter32();
	
	@Source("table-union_32.png")
	ImageResource union32();
	
	
	
	@Source("table-denormalize_32.png")
	ImageResource tableDenormalize32();
	
	@Source("table-denormalize.png")
	ImageResource tableDenormalize();
	
	@Source("table-normalize_32.png")
	ImageResource tableNormalize32();
	
	@Source("table-normalize.png")
	ImageResource tableNormalize();
	
	@Source("table-expand_32.png")
	ImageResource tableExpand32();
	
	@Source("table-expand.png")
	ImageResource tableExpand();
	
	
	@Source("table-group_32.png")
	ImageResource group32();
	
	@Source("table-aggregate.png")
	ImageResource aggregate();
	
	@Source("table-aggregate_32.png")
	ImageResource aggregate32();
	
	
	@Source("history_32.png") 
	ImageResource history32();
	
	@Source("arrow-undo_32.png")
	ImageResource discard32();
	
	@Source("arrow-undo.png")
	ImageResource discard();
	
	@Source("arrow-undo-all_32.png")
	ImageResource discardAll32();
	
	@Source("arrow-undo-all.png")
	ImageResource discardAll();
	
	@Source("column-type_32.png")
	ImageResource columnType32();
	
	@Source("column-type.png")
	ImageResource columnType();
	
	@Source("column-label_32.png")
	ImageResource columnLabel32();
	
	@Source("column-label.png")
	ImageResource columnLabel();
	
	@Source("column-filter_32.png")
	ImageResource columnFilter32();
	
	@Source("column-filter.png")
	ImageResource columnFilter();
	
	
	@Source("column-edit_32.png")
	ImageResource columnEdit32();
	
	@Source("column-edit.png")
	ImageResource columnEdit();
	
	@Source("column-delete_32.png")
	ImageResource columnDelete32();
	
	@Source("column-delete.png")
	ImageResource columnDelete();

	@Source("column-add_32.png")
	ImageResource columnAdd32();
	
	@Source("column-add.png")
	ImageResource columnAdd();
	
	@Source("column-values_32.png")
	ImageResource columnValues32();
	
	@Source("column-values.png")
	ImageResource columnValues();
	
	@Source("column-replace.png")
	ImageResource columnReplace();
	
	@Source("column-replace_32.png")
	ImageResource columnReplace32();
	
	@Source("column-replace-batch.png")
	ImageResource columnReplaceBatch();
	
	@Source("column-replace-batch_32.png")
	ImageResource columnReplaceBatch32();
	
	
	@Source("column_32.png")
	ImageResource column32();
	
	@Source("column.png")
	ImageResource column();
	
	@Source("cog_32.png")
	ImageResource cog32();
	
	@Source("cog.png")
	ImageResource cog();
	
	@Source("delete_32.png")
	ImageResource delete32();
	
	@Source("delete.png")
	ImageResource delete();
	
	@Source("rule-add_32.png")
	ImageResource ruleAdd32();
	
	@Source("rule-add.png")
	ImageResource ruleAdd();
	
	@Source("validate-add_32.png")
	ImageResource validateAdd32();
	
	@Source("validate-add.png")
	ImageResource validateAdd();
	
	
	@Source("pencil_32.png")
	ImageResource rowEdit32();
	
	@Source("pencil.png")
	ImageResource rowEdit();
	
	@Source("table-row-insert_32.png")
	ImageResource rowInsert32();
	
	@Source("table-row-insert.png")
	ImageResource rowInsert();
	
	@Source("table-row-delete_32.png")
	ImageResource rowRemove32();
	
	@Source("table-row-delete.png")
	ImageResource rowRemove();
	
	@Source("help_32.png")
	ImageResource help32();
	
	@Source("help.png")
	ImageResource help();
	
	@Source("logs_32.png")
	ImageResource logs32();
	
	@Source("logs.png")
	ImageResource logs();
	
	@Source("template-add_32.png")
	ImageResource templateAdd32();
	
	@Source("template-add.png")
	ImageResource templateAdd();
	
	@Source("template-edit_32.png")
	ImageResource templateEdit32();
	
	@Source("template-edit.png")
	ImageResource templateEdit();
	
	@Source("template-delete.png")
	ImageResource templateDelete();
	
	@Source("template-delete_32.png")
	ImageResource templateDelete32();
	
	@Source("template-apply.png")
	ImageResource templateApply();
	
	@Source("template-apply_32.png")
	ImageResource templateApply32();
	
	@Source("timeline_32.png")
	ImageResource timeline32();
	
	@Source("timeline.png")
	ImageResource timeline();
	
	@Source("wrench-manage_32.png")
	ImageResource wrenchManage32();
	
	@Source("wrench-manage.png")
	ImageResource wrenchManage();
	
	@Source("table-duplicate-rows_32.png")
	ImageResource tableDuplicateRows32();
	
	@Source("table-duplicate-rows.png")
	ImageResource tableDuplicateRows();
	
	@Source("table-duplicate-rows-remove_32.png")
	ImageResource tableDuplicateRowsRemove32();
	
	@Source("table-duplicate-rows-remove.png")
	ImageResource tableDuplicateRowsRemove();
	
	@Source("table-type_32.png")
	ImageResource tableType32();
	
	@Source("table-type.png")
	ImageResource tableType();
	
	@Source("codelist_32.png")
	ImageResource codelist32();
	
	@Source("codelist.png")
	ImageResource codelist();
	
	@Source("summary_32.png")
	ImageResource summary32();
	
	@Source("summary.png")
	ImageResource summary();
	
	@Source("tag-blue-add_32.png")
	ImageResource annotationAdd32();
	
	@Source("tag-blue-add.png")
	ImageResource annotationAdd();
	
	@Source("tag-blue-delete_32.png")
	ImageResource annotationDelete32();
	
	@Source("tag-blue-delete.png")
	ImageResource annotationDelete();
	
	@Source("table-clone_32.png")
	ImageResource tableClone32();
	
	@Source("table-clone.png")
	ImageResource tableClone();
	
	@Source("tabular-resource-clone_32.png")
	ImageResource clone32();
	
	@Source("tabular-resource-clone.png")
	ImageResource clone();
	
	
	@Source("codelistmapping_32.png")
	ImageResource codelistMapping32();
	
	@Source("codelistmapping.png")
	ImageResource codelistMapping();
	
	@Source("column-split_32.png")
	ImageResource columnSplit32();
	
	@Source("column-split.png")
	ImageResource columnSplit();
	
	@Source("column-merge_32.png")
	ImageResource columnMerge32();
	
	@Source("column-merge.png")
	ImageResource columnMerge();
	
	@Source("basket-background_32.png")
	ImageResource basketBackground32();
	
	@Source("basket-background.png")
	ImageResource basketBackground();
	
	@Source("column-replace-by-expression_32.png")
	ImageResource columnReplaceByExpression32();
	
	@Source("column-replace-by-expression.png")
	ImageResource columnReplaceByExpression();
	
}

==> tabular-data-manager-2.5.0-20141027.100751-1-sources.jar: org/gcube/portlets/user/td/client/resource/TabularDataResources.java <==
/**
 * 
 */
package org.gcube.portlets.user.td.client.resource;

import com.google.gwt.core.client.GWT;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.ImageResource;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 *
 */
public interface TabularDataResources extends ClientBundle {

	public static final TabularDataResources INSTANCE = GWT
			.create(TabularDataResources.class);

	@Source("arrow-refresh_32.png")
	ImageResource refresh32();

	@Source("arrow-refresh.png")
	ImageResource refresh();

	@Source("page-white-add_32.png")
	ImageResource open32();

	@Source("page-white-close_32.png")
	ImageResource close32();

	@Source("page-white-close.png")
	ImageResource close();

	@Source("page-white-share_32.png")
	ImageResource share32();

	@Source("page-white-share.png")
	ImageResource share();

	@Source("disk.png")
	ImageResource save();

	@Source("disk_32.png")
	ImageResource save32();

	@Source("properties.png")
	ImageResource properties();

	@Source("sdmx.png")
	ImageResource sdmx();

	@Source("sdmx_32.png")
	ImageResource sdmx32();

	@Source("gis.png")
	ImageResource gis();

	@Source("gis_32.png")
	ImageResource gis32();

	@Source("csv.png")
	ImageResource csv();

	@Source("json.png")
	ImageResource json();

	@Source("chart-bar.png")
	ImageResource chart();

	@Source("chart-bar_32.png")
	ImageResource chartBar32();

	@Source("chart-bulls.png")
	ImageResource chartBulls();

	@Source("chart-bulls_32.png")
	ImageResource chartBulls32();

	@Source("chart-curve.png")
	ImageResource chartCurve();

	@Source("chart-curve_32.png")
	ImageResource chartCurve32();

	@Source("chart-pie.png")
	ImageResource chartPie();

	@Source("chart-pie_32.png")
	ImageResource chartPie32();

	@Source("RStudio.png")
	ImageResource rstudio();

	@Source("RStudio_32.png")
	ImageResource rstudio32();

	@Source("statistical.png")
	ImageResource statistical();

	@Source("statistical_32.png")
	ImageResource statistical32();

	@Source("table-validate_32.png")
	ImageResource validation32();

	@Source("table-validate.png")
	ImageResource validation();

	@Source("rules.png")
	ImageResource rules();

	@Source("rules_32.png")
	ImageResource rules32();

	@Source("table-filter_32.png")
	ImageResource filter32();

	@Source("table-union_32.png")
	ImageResource union32();

	@Source("table-denormalize_32.png")
	ImageResource tableDenormalize32();

	@Source("table-denormalize.png")
	ImageResource tableDenormalize();

	@Source("table-normalize_32.png")
	ImageResource tableNormalize32();

	@Source("table-normalize.png")
	ImageResource tableNormalize();

	@Source("table-expand_32.png")
	ImageResource tableExpand32();

	@Source("table-expand.png")
	ImageResource tableExpand();

	@Source("table-group_32.png")
	ImageResource group32();

	@Source("table-aggregate.png")
	ImageResource aggregate();

	@Source("table-aggregate_32.png")
	ImageResource aggregate32();

	@Source("history_32.png")
	ImageResource history32();

	@Source("arrow-undo_32.png")
	ImageResource discard32();

	@Source("arrow-undo.png")
	ImageResource discard();

	@Source("arrow-undo-all_32.png")
	ImageResource discardAll32();

	@Source("arrow-undo-all.png")
	ImageResource discardAll();

	@Source("column-type_32.png")
	ImageResource columnType32();

	@Source("column-type.png")
	ImageResource columnType();

	@Source("column-label_32.png")
	ImageResource columnLabel32();

	@Source("column-label.png")
	ImageResource columnLabel();

	@Source("column-filter_32.png")
	ImageResource columnFilter32();

	@Source("column-filter.png")
	ImageResource columnFilter();

	@Source("column-edit_32.png")
	ImageResource columnEdit32();

	@Source("column-edit.png")
	ImageResource columnEdit();

	@Source("column-delete_32.png")
	ImageResource columnDelete32();

	@Source("column-delete.png")
	ImageResource columnDelete();

	@Source("column-add_32.png")
	ImageResource columnAdd32();

	@Source("column-add.png")
	ImageResource columnAdd();

	@Source("column-values_32.png")
	ImageResource columnValues32();

	@Source("column-values.png")
	ImageResource columnValues();

	@Source("column-replace.png")
	ImageResource columnReplace();

	@Source("column-replace_32.png")
	ImageResource columnReplace32();

	@Source("column-replace-batch.png")
	ImageResource columnReplaceBatch();

	@Source("column-replace-batch_32.png")
	ImageResource columnReplaceBatch32();

	@Source("column_32.png")
	ImageResource column32();

	@Source("column.png")
	ImageResource column();

	@Source("cog_32.png")
	ImageResource cog32();

	@Source("cog.png")
	ImageResource cog();

	@Source("delete_32.png")
	ImageResource delete32();

	@Source("delete.png")
	ImageResource delete();

	@Source("rule-add_32.png")
	ImageResource ruleAdd32();

	@Source("rule-add.png")
	ImageResource ruleAdd();

	@Source("validate-add_32.png")
	ImageResource validateAdd32();

	@Source("validate-add.png")
	ImageResource validateAdd();

	@Source("pencil_32.png")
	ImageResource rowEdit32();

	@Source("pencil.png")
	ImageResource rowEdit();

	@Source("table-row-insert_32.png")
	ImageResource rowInsert32();

	@Source("table-row-insert.png")
	ImageResource rowInsert();

	@Source("table-row-delete_32.png")
	ImageResource rowRemove32();

	@Source("table-row-delete.png")
	ImageResource rowRemove();

	@Source("help_32.png")
	ImageResource help32();

	@Source("help.png")
	ImageResource help();

	@Source("logs_32.png")
	ImageResource logs32();

	@Source("logs.png")
	ImageResource logs();

	@Source("template-add_32.png")
	ImageResource templateAdd32();

	@Source("template-add.png")
	ImageResource templateAdd();

	@Source("template-edit_32.png")
	ImageResource templateEdit32();

	@Source("template-edit.png")
	ImageResource templateEdit();

	@Source("template-delete.png")
	ImageResource templateDelete();

	@Source("template-delete_32.png")
	ImageResource templateDelete32();

	@Source("template-apply.png")
	ImageResource templateApply();

	@Source("template-apply_32.png")
	ImageResource templateApply32();

	@Source("template-share.png")
	ImageResource templateShare();

	@Source("template-share_32.png")
	ImageResource templateShare32();

	@Source("timeline_32.png")
	ImageResource timeline32();

	@Source("timeline.png")
	ImageResource timeline();

	@Source("wrench-manage_32.png")
	ImageResource wrenchManage32();

	@Source("wrench-manage.png")
	ImageResource wrenchManage();

	@Source("table-duplicate-rows_32.png")
	ImageResource tableDuplicateRows32();

	@Source("table-duplicate-rows.png")
	ImageResource tableDuplicateRows();

	@Source("table-duplicate-rows-remove_32.png")
	ImageResource tableDuplicateRowsRemove32();

	@Source("table-duplicate-rows-remove.png")
	ImageResource tableDuplicateRowsRemove();

	@Source("table-type_32.png")
	ImageResource tableType32();

	@Source("table-type.png")
	ImageResource tableType();

	@Source("codelist_32.png")
	ImageResource codelist32();

	@Source("codelist.png")
	ImageResource codelist();

	@Source("summary_32.png")
	ImageResource summary32();

	@Source("summary.png")
	ImageResource summary();

	@Source("tag-blue-add_32.png")
	ImageResource annotationAdd32();

	@Source("tag-blue-add.png")
	ImageResource annotationAdd();

	@Source("tag-blue-delete_32.png")
	ImageResource annotationDelete32();

	@Source("tag-blue-delete.png")
	ImageResource annotationDelete();

	@Source("table-clone_32.png")
	ImageResource tableClone32();

	@Source("table-clone.png")
	ImageResource tableClone();

	@Source("tabular-resource-clone_32.png")
	ImageResource clone32();

	@Source("tabular-resource-clone.png")
	ImageResource clone();

	@Source("codelistmapping_32.png")
	ImageResource codelistMapping32();

	@Source("codelistmapping.png")
	ImageResource codelistMapping();

	@Source("column-split_32.png")
	ImageResource columnSplit32();

	@Source("column-split.png")
	ImageResource columnSplit();

	@Source("column-merge_32.png")
	ImageResource columnMerge32();

	@Source("column-merge.png")
	ImageResource columnMerge();

	@Source("basket-background_32.png")
	ImageResource basketBackground32();

	@Source("basket-background.png")
	ImageResource basketBackground();

	@Source("column-replace-by-expression_32.png")
	ImageResource columnReplaceByExpression32();

	@Source("column-replace-by-expression.png")
	ImageResource columnReplaceByExpression();

}
